
from django.utils.translation import ugettext_lazy as _


CURRENCY_UAH = 980
CURRENCY_USD = 840
CURRENCY_EUR = 978

CURRENCIES = (
    (CURRENCY_UAH, _('UAH')),
    (CURRENCY_USD, _('USD')),
    (CURRENCY_EUR, _('EUR')),
)

CURRENCY_NAMES = {
    CURRENCY_UAH: 'uah',
    CURRENCY_USD: 'usd',
    CURRENCY_EUR: 'eur'
}

DEFAULT_CURRENCY = CURRENCY_UAH

CURRENCY_SESSION_KEY = 'CURRENCY'




from django.db import models

from exchange.querysets import MultiCurrencyQuerySet


class MultiCurrencyManager(models.Manager):

    def get_queryset(self):
        return MultiCurrencyQuerySet(self.model, using=self._db)

    def set_currency(self, value):
        return self.get_queryset().set_currency(value)




from django.contrib import admin

from solo.admin import SingletonModelAdmin

from exchange.models import ExchangeRates


@admin.register(ExchangeRates)
class ExchangeRatesAdmin(SingletonModelAdmin):

    list_display = ['id', 'usd', 'eur']
    list_editable = ['usd', 'eur']




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class ExchangeAppConfig(AppConfig):

    name = 'exchange'
    verbose_name = _('Exchange')


default_app_config = 'exchange.ExchangeAppConfig'




class ExchangeSettings(object):

    PRICE_MODEL = 'exchange.models.MultiCurrencyPrice'

    @property
    def INSTALLED_APPS(self):
        return super().INSTALLED_APPS + ['exchange']

    @property
    def CONTEXT_PROCESSORS(self):
        return super().CONTEXT_PROCESSORS + [
            'exchange.context_processors.currencies'
        ]




from django.utils.translation import ugettext_lazy as _

from cap.decorators import short_description
from exchange.models import ExchangeRates


@short_description(_('Recalculate prices'))
def recalculate_prices(modeladmin, request, queryset):
    ExchangeRates.update_prices(queryset)
